import React, { useState } from 'react';
import { View, StyleSheet, Dimensions, Alert } from 'react-native';
import MapView from 'react-native-maps';
import CustomGeojson from '../components/CustomGeojson';
import { BUILDINGS_CZU } from '../data/geodata/buildings/buildings-czu';
import { DEPARTMENT_OF_PHYSICAL_EDUCATION } from '../data/geodata/buildings/department-of-physical-education';
import {
	DORMITORY_A,
	DORMITORY_BCD,
	DORMITORY_JIH,
	DORMITORY_EFG,
} from '../data/geodata/buildings/dormitory';
import { LIBRARY_CZU, CASH_DESK } from '../data/geodata/buildings/library-czu';
import {
	PUBLIC_TRANSPORT,
	PUBLIC_TRANSPORT_TICKETS,
} from '../data/geodata/buildings/public-transport';
import {
	FAFNR,
	FE,
	FEM,
	FFWT,
	FES,
	FTA,
} from '../data/geodata/buildings/faculties';

const BuildingsMap = (props) => {
	const [mapRegion, setMapRegion] = useState({
		latitude: 50.130398,
		longitude: 14.37491,
		latitudeDelta: 0.015,
		longitudeDelta: 0.015,
	});

	const mapStyle = [
		{
			featureType: 'administrative',
			elementType: 'geometry',
			stylers: [
				{
					visibility: 'off',
				},
			],
		},
		{
			featureType: 'poi',
			stylers: [
				{
					visibility: 'off',
				},
			],
		},
		{
			featureType: 'road',
			elementType: 'labels.icon',
			stylers: [
				{
					visibility: 'off',
				},
			],
		},
		{
			featureType: 'transit',
			stylers: [
				{
					visibility: 'off',
				},
			],
		},
	];

	const handlePress = (overlay) => {
		const { Name, description } = overlay.feature.properties;

		Alert.alert(Name, description, [{ text: 'OK', onPress: () => {} }], {
			cancelable: true,
		});
	};

	return (
		<View style={styles.container}>
			<MapView
				style={styles.map}
				region={mapRegion}
				customMapStyle={mapStyle}
				tappable={true}
			>
				<CustomGeojson
					geojson={BUILDINGS_CZU}
					strokeColor="white"
					fillColor="#097138"
					strokeWidth={1}
					image={require('../assets/images/map/czu-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={DEPARTMENT_OF_PHYSICAL_EDUCATION}
					strokeColor="white"
					fillColor="#b2ebf2"
					strokeWidth={1}
					image={require('../assets/images/map/sport-center-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={DORMITORY_A}
					strokeColor="white"
					fillColor="#9fa8da"
					strokeWidth={1}
					image={require('../assets/images/map/dorm-a-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={DORMITORY_BCD}
					strokeColor="white"
					fillColor="#9fa8da"
					strokeWidth={1}
					image={require('../assets/images/map/dorm-bcd-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={DORMITORY_EFG}
					strokeColor="white"
					fillColor="#9fa8da"
					strokeWidth={1}
					image={require('../assets/images/map/dorm-efg-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={DORMITORY_JIH}
					strokeColor="white"
					fillColor="#9fa8da"
					strokeWidth={1}
					image={require('../assets/images/map/dorm-jih-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={LIBRARY_CZU}
					strokeColor="white"
					fillColor="#880e4f"
					strokeWidth={1}
					image={require('../assets/images/map/library-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={CASH_DESK}
					strokeColor="white"
					fillColor="#880e4f"
					strokeWidth={1}
					image={require('../assets/images/map/cashdesk-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={PUBLIC_TRANSPORT}
					strokeColor="white"
					fillColor="#097138"
					strokeWidth={1}
					image={require('../assets/images/map/bus-blue.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={PUBLIC_TRANSPORT_TICKETS}
					strokeColor="white"
					fillColor="#097138"
					strokeWidth={1}
					image={require('../assets/images/map/ticket-automat.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={FAFNR}
					strokeColor="white"
					fillColor="#fbc02d"
					strokeWidth={1}
					image={require('../assets/images/map/fafnr-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={FE}
					strokeColor="white"
					fillColor="#01579b"
					strokeWidth={1}
					image={require('../assets/images/map/fe-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={FEM}
					strokeColor="white"
					fillColor="#a52714"
					strokeWidth={1}
					image={require('../assets/images/map/fem-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={FFWT}
					strokeColor="white"
					fillColor="#7cb342"
					strokeWidth={1}
					image={require('../assets/images/map/ffws-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={FES}
					strokeColor="white"
					fillColor="#0097a7"
					strokeWidth={1}
					image={require('../assets/images/map/fes-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
				<CustomGeojson
					geojson={FTA}
					strokeColor="white"
					fillColor="#f57c00"
					strokeWidth={1}
					image={require('../assets/images/map/fta-map-icon.png')}
					tappable={true}
					onPress={handlePress}
				/>
			</MapView>
		</View>
	);
};

const styles = StyleSheet.create({
	container: {
		flex: 1,
		backgroundColor: '#fff',
		alignItems: 'center',
		justifyContent: 'center',
	},
	map: {
		width: Dimensions.get('window').width,
		height: Dimensions.get('window').height,
	},
});

export default BuildingsMap;
