import React from 'react';
import { View, StyleSheet, ImageBackground, ScrollView } from 'react-native';
import Paragraph from '../components/Paragraph';
import DefaultText from '../components/DefaultText';

const ForewordScreen = (props) => {
	return (
		<ScrollView>
			<View style={styles.imageContainer}>
				<ImageBackground
					source={require('../assets/images/content/rektor-short.jpg')}
					style={styles.image}
				>
					<View style={styles.nameContainer}>
						<DefaultText style={styles.name}>
							prof. Ing. Petr Sklenička, CSc.
						</DefaultText>
					</View>
				</ImageBackground>
			</View>
			<View style={styles.textContainer}>
				<Paragraph>Dear students,</Paragraph>
				<Paragraph>
					Studying in Prague is a great choice. Studying at the Czech
					University of Life Sciences Prague (CZU) is an even better
					choice. There are few beautiful campuses in Europe like
					ours, full of greenery and open areas, providing plenty of
					opportunities for sports and cultural events along with
					modern buildings featuring state-of-the-art laboratories and
					classrooms. All of this is located on the outskirts of
					Prague, only 20 minutes from the city centre. As a student,
					I spent many wonderful years here, and I know that the
					environment where you intend to spend a piece of your life
					matters.
				</Paragraph>
				<Paragraph>
					The Czech University of Life Sciences Prague offers a full
					range of engaging study programmes at the bachelor‘s,
					master‘s and doctoral levels. Today, the programmes are
					designed to prepare professionals to be capable of
					addressing the greatest challenges of our time. These
					include food safety, society‘s adaptation to climate change,
					the fourth industrial revolution in agriculture and
					forestry, renewable energy, and biodiversity protection.
				</Paragraph>
				<Paragraph>
					Studying life sciences is modern and far-sighted. These are
					mostly programmes that are crucial to the quality of life
					today and in the future. At present, quality of life is not
					only determined by the economic advancement of society, but
					increasingly by health care, education levels, food quality,
					clean water availability, protection of traditions, and
					natural or cultural values.
				</Paragraph>
				<Paragraph>
					At CZU, we place great emphasis on linking research and
					teaching. This has helped to maintain the quality of
					education at a high European level. With more than 19,000
					students, we are among the six largest universities in the
					Czech Republic. Together with six other prestigious European
					universities, we form the Euroleague for Life Sciences,
					which enables the above-standard exchange of students and
					cooperation in research.
				</Paragraph>
				<Paragraph>
					Dear students, I believe that you will enjoy studying at our
					university as much as possible and I am sure that it will
					provide you with a solid foundation for your successful
					future career.
				</Paragraph>
			</View>
		</ScrollView>
	);
};

ForewordScreen.navigationOptions = (navigationData) => {
	return {
		headerTitle: 'Foreword by the Rector',
	};
};

const styles = StyleSheet.create({
	imageContainer: {
		flex: 1,
		justifyContent: 'flex-end',
		alignItems: 'flex-end',
		height: 250,
		marginBottom: 10,
	},
	image: {
		width: '100%',
		height: '100%',
		justifyContent: 'flex-end',
	},
	nameContainer: {
		backgroundColor: 'rgba(0,0,0, 0.5)',
		paddingVertical: 10,
		paddingHorizontal: 15,
	},
	name: {
		fontFamily: 'open-sans',
		fontSize: 18,
		color: 'white',
		textAlign: 'right',
	},
	textContainer: {
		paddingVertical: 10,
		paddingHorizontal: 20,
	},
});

export default ForewordScreen;
