import React from 'react';
import { View, StyleSheet, ScrollView, Image } from 'react-native';
import Paragraph from '../../components/Paragraph';
import StrongText from '../../components/StrongText';
import Title from '../../components/Title';
import ListItem from '../../components/ListItem';
import AccentParagraph from '../../components/AccentParagraph';
import TextLink from '../../components/TextLink';

const AgrobiologyScreen = (props) => {
	return (
		<ScrollView>
			<View>
				<Image
					style={styles.image}
					resizeMode="cover"
					source={require('../../assets/images/faculties/fafnr-cover.jpg')}
				/>
			</View>
			<View style={styles.textContainer}>
				<Paragraph>
					The faculty offers students a wide range of education
					covering the fields of agriculture, aquacultural and
					horticultural production, garden architecture, pet breeding,
					sustainable use of natural resources, food quality and
					safety including human nutrition and rural development.
				</Paragraph>
				<View>
					<ListItem>
						Over 4,000 students are studying at the faculty, and
						more than 300 employees work here.
					</ListItem>
					<ListItem>
						The faculty consists of 16 departments and 10 other
						workplaces.
					</ListItem>
					<ListItem>The dean: prof. Ing. Iva Langrová, CSc.</ListItem>
				</View>
				<AccentParagraph backgroundColor="#ea952d">
					<Title style={styles.whiteText}>Contacts</Title>
					<View>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-earth"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://af.czu.cz"
							>
								af.czu.cz
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-twitter"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://twitter.com/agro_czu"
							>
								twitter.com/agro_czu
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-facebook"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://facebook.com/af.czu.cz"
							>
								facebook.com/af.czu.cz
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-instagram"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://instagram.com/af.czu.cz"
							>
								instagram.com/af.czu.cz
							</TextLink>
						</ListItem>
					</View>
				</AccentParagraph>
				<Title>Study Administration Office</Title>
				<StrongText>Head of the Study Administration Office</StrongText>
				<View>
					<ListItem pointerIcon="ios-person">
						Ing. Jitka Voženílková
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 384 668"
						>
							+420 224 384 668
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:vozenilkova@af.czu.cz"
						>
							vozenilkova@af.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">
						room FAPPZ/AF115
					</ListItem>
				</View>
				<Title>International Relations Office</Title>
				<View style={{ marginBottom: 10 }}>
					<ListItem pointerIcon="ios-person">
						Ing. Jitka Kloučková
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 384 577"
						>
							+420 224 384 577
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:klouckova@af.czu.cz"
						>
							klouckova@af.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:iro@af.czu.cz"
						>
							iro@af.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">
						room FAPPZ/AF120
					</ListItem>
				</View>
				<View>
					<ListItem pointerIcon="ios-person">
						Ing. Dagmar Brožová
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 384 577"
						>
							+420 224 384 577
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:brozovadagmar@af.czu.cz"
						>
							brozovadagmar@af.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">
						room FAPPZ/AF120
					</ListItem>
				</View>
			</View>
		</ScrollView>
	);
};

AgrobiologyScreen.navigationOptions = (navigationData) => {
	return {
		headerTitle: 'Faculty of Agrobiology, Food and Natural Resources',
		headerStyle: {
			backgroundColor: '#ea952d',
		},
	};
};

const styles = StyleSheet.create({
	image: {
		width: '100%',
		height: 100,
	},
	textContainer: {
		paddingVertical: 10,
		paddingHorizontal: 20,
	},
	whiteText: {
		color: 'white',
		marginBottom: 5,
	},
	accentLink: {
		color: 'white',
		fontFamily: 'open-sans',
	},
	normalLink: {
		color: 'black',
		fontFamily: 'open-sans',
	},
});

export default AgrobiologyScreen;
