import React from 'react';
import { View, StyleSheet, ScrollView, Image } from 'react-native';
import Paragraph from '../../components/Paragraph';
import Title from '../../components/Title';
import ListItem from '../../components/ListItem';
import AccentParagraph from '../../components/AccentParagraph';
import TextLink from '../../components/TextLink';

const EngineeringScreen = (props) => {
	return (
		<ScrollView>
			<View>
				<Image
					style={styles.image}
					resizeMode="cover"
					source={require('../../assets/images/faculties/fe-cover.jpg')}
				/>
			</View>
			<View style={styles.textContainer}>
				<Paragraph>
					The Faculty of Engineering offers students a wide range of
					education covering the fields of agricultural technology,
					road and automobile transport, waste treatment technology
					and techniques, technological building management, trade in
					technology or maintenance engineering.
				</Paragraph>
				<View>
					<ListItem>
						Over 1,000 students are studying at the faculty, and
						more than 100 employees work here.
					</ListItem>
					<ListItem>
						The faculty consists of 10 departments and 4 other
						workplaces.
					</ListItem>
					<ListItem>The dean: doc. Ing. Jiří Mašek, Ph.D.</ListItem>
				</View>
				<AccentParagraph backgroundColor="#373188">
					<Title style={styles.whiteText}>Contacts</Title>
					<View>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-earth"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://www.tf.czu.cz/en"
							>
								tf.czu.cz
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-facebook"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://facebook.com/int.tf.czu.cz"
							>
								facebook.com/int.tf.czu.cz
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-instagram"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://nase.technika.czu"
							>
								nase.technika.czu
							</TextLink>
						</ListItem>
					</View>
				</AccentParagraph>
				<Title>International Relations Office</Title>
				<View style={{ marginBottom: 10 }}>
					<ListItem pointerIcon="ios-person">
						Ing. Monika Divišová
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 383 212"
						>
							+420 224 383 212
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:divisovamonika@tf.czu.cz"
						>
							divisovamonika@tf.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">
						room TF/45/II
					</ListItem>
				</View>
				<View>
					<ListItem pointerIcon="ios-person">
						Lucie Korečková
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 383 212"
						>
							+420 224 383 212
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:mareckoval@tf.czu.cz"
						>
							mareckoval@tf.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">
						room TF/45/II
					</ListItem>
				</View>
			</View>
		</ScrollView>
	);
};

EngineeringScreen.navigationOptions = (navigationData) => {
	return {
		headerTitle: 'Faculty of Engineering',
		headerStyle: {
			backgroundColor: '#373188',
		},
	};
};

const styles = StyleSheet.create({
	image: {
		width: '100%',
		height: 100,
	},
	textContainer: {
		paddingVertical: 10,
		paddingHorizontal: 20,
	},
	whiteText: {
		color: 'white',
		marginBottom: 5,
	},
	accentLink: {
		color: 'white',
		fontFamily: 'open-sans',
	},
	normalLink: {
		color: 'black',
		fontFamily: 'open-sans',
	},
});

export default EngineeringScreen;
