import React from 'react';
import { View, StyleSheet, ScrollView, Image } from 'react-native';
import Paragraph from '../../components/Paragraph';
import StrongText from '../../components/StrongText';
import Title from '../../components/Title';
import ListItem from '../../components/ListItem';
import AccentParagraph from '../../components/AccentParagraph';
import TextLink from '../../components/TextLink';

const ForestryScreen = (props) => {
	return (
		<ScrollView>
			<View>
				<Image
					style={styles.image}
					resizeMode="cover"
					source={require('../../assets/images/faculties/ffws-cover.jpg')}
				/>
			</View>
			<View style={styles.textContainer}>
				<Paragraph>
					The faculty offers students a wide range of education
					covering the fields of forestry, wood sciences, game
					management and conservation of natural products and
					taxidermy.
				</Paragraph>
				<View>
					<ListItem>
						About 2,000 students are studying at the faculty, and
						more than 100 employees work here.
					</ListItem>
					<ListItem>
						The faculty consists of 10 departments and 5 other
						workplaces.
					</ListItem>
					<ListItem>
						The dean: prof. Ing. Róbert Marušák, Ph.D.
					</ListItem>
				</View>
				<AccentParagraph backgroundColor="#4b9846">
					<Title style={styles.whiteText}>Contacts</Title>
					<View>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-earth"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://www.fld.czu.cz/en"
							>
								fld.czu.cz
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-twitter"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://twitter.com/CzuFld"
							>
								twitter.com/CzuFld
							</TextLink>
							twitter.com/CzuFld
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-facebook"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://facebook.com/fld.czu.cz"
							>
								facebook.com/fld.czu.cz
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-instagram"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://instagram.com/lesarna"
							>
								instagram.com/lesarna
							</TextLink>
						</ListItem>
						<ListItem
							style={styles.whiteText}
							pointerColor="white"
							pointerIcon="ios-logo-youtube"
						>
							<TextLink
								style={styles.accentLink}
								linkTo="https://youtube.com/FLDvPraze"
							>
								youtube.com/FLDvPraze
							</TextLink>
						</ListItem>
					</View>
				</AccentParagraph>
				<Title>Study Administration Office</Title>
				<StrongText>Head of the Study Administration Office</StrongText>
				<View>
					<ListItem pointerIcon="ios-person">
						Ing. František Stehlík
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 383 710"
						>
							+420 224 383 710
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:stehlik@fld.czu.cz"
						>
							stehlik@fld.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">room FLD/156</ListItem>
				</View>
				<StrongText>
					Coordinator of bachelor‘s programmes taught in English
				</StrongText>
				<View>
					<ListItem pointerIcon="ios-person">
						Bc. Jana Simandlová
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 383 743"
						>
							+420 224 383 743
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:simandlovaj@fld.czu.cz"
						>
							simandlovaj@fld.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">room FLD/155</ListItem>
				</View>
				<StrongText>
					Coordinator of master‘s degree programmes taught in English
				</StrongText>
				<View>
					<ListItem pointerIcon="ios-person">
						Ing. František Stehlík
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 383 710"
						>
							+420 224 383 710
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:stehlik@fld.czu.cz"
						>
							stehlik@fld.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">room FLD/156</ListItem>
				</View>
				<Title>International Relations Office</Title>
				<View style={{ marginBottom: 10 }}>
					<ListItem pointerIcon="ios-person">
						Ing. Kateřina Navrátilová
					</ListItem>
					<ListItem pointerIcon="ios-call">
						<TextLink
							style={styles.normalLink}
							linkTo="tel:+420 224 384 871"
						>
							+420 224 384 871
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-mail">
						<TextLink
							style={styles.normalLink}
							linkTo="mailto:navratilova@fld.czu.cz"
						>
							navratilova@fld.czu.cz
						</TextLink>
					</ListItem>
					<ListItem pointerIcon="ios-location">room FLD/128</ListItem>
				</View>
			</View>
		</ScrollView>
	);
};

ForestryScreen.navigationOptions = (navigationData) => {
	return {
		headerTitle: 'Faculty of Forestry and Wood Sciences',
		headerStyle: {
			backgroundColor: '#4b9846',
		},
	};
};

const styles = StyleSheet.create({
	image: {
		width: '100%',
		height: 100,
	},
	textContainer: {
		paddingVertical: 10,
		paddingHorizontal: 20,
	},
	whiteText: {
		color: 'white',
		marginBottom: 5,
	},
	accentLink: {
		color: 'white',
		fontFamily: 'open-sans',
	},
	normalLink: {
		color: 'black',
		fontFamily: 'open-sans',
	},
});

export default ForestryScreen;
