import React from 'react';
import { View, StyleSheet, ScrollView, Image } from 'react-native';
import Paragraph from '../../components/Paragraph';
import Title from '../../components/Title';
import ListItem from '../../components/ListItem';
import TextLink from '../../components/TextLink';

const StudentAssociationsScreen = (props) => {
	return (
		<ScrollView>
			<View>
				<Image
					style={styles.image}
					resizeMode="cover"
					source={require('../../assets/images/content/student-associations.jpg')}
				/>
			</View>
			<View style={styles.textContainer}>
				<Paragraph>
					Several student associations and groups host programmes for
					those with an active social life. If you want to get
					involved in events, there is a wide selection to choose
					from. These associations organize events of all kinds, such
					as university newspapers, special interest groups, and
					engaging in volunteering or sustainable development.
				</Paragraph>
				<Paragraph>
					For international students, the most significant student
					association is most likely ESN CZU Prague (Erasmus Student
					Network). Their mission is to represent international
					students by providing opportunities for cultural
					understanding and self-development under the principle of
					students helping students. They organize a variety of events
					which you can check on their website:{' '}
					<TextLink linkTo="https://esnczu.cz">esnczu.cz</TextLink> or
					Facebook page (
					<TextLink linkTo="https://www.facebook.com/esnczuprague/">
						@esnczu
					</TextLink>
					). If you are interested in any kind of their activity, you
					can also join them as a volunteer. For that, contact
					<TextLink linkTo="mailto:hr@esnczu.cz">
						hr@esnczu.cz
					</TextLink>
					.
				</Paragraph>
				<Title>Traditional events on and off-campus</Title>
				<Paragraph>
					A variety of events take place on the CZU premises during
					the year, whether directed by students, the university or
					other entities.
				</Paragraph>
				<View>
					<ListItem>Open days (November, January and March)</ListItem>
					<ListItem>Job Fair (February)</ListItem>
					<ListItem>CZU Ball (March)</ListItem>
					<ListItem>Miss Agro (May)</ListItem>
					<ListItem>Rector‘s Day (May)</ListItem>
					<ListItem>Open-air cinema (May)</ListItem>
					<ListItem>CZU Film Fest (October / November)</ListItem>
					<ListItem>Wine Festival (November)</ListItem>
					<ListItem>And many others</ListItem>
				</View>
			</View>
		</ScrollView>
	);
};

StudentAssociationsScreen.navigationOptions = (navigationData) => {
	return {
		headerTitle: 'Student associations',
	};
};

const styles = StyleSheet.create({
	image: {
		width: '100%',
		height: 100,
	},
	textContainer: {
		paddingVertical: 10,
		paddingHorizontal: 20,
	},
});

export default StudentAssociationsScreen;
