import React from 'react';
import { View, StyleSheet, ScrollView } from 'react-native';
import Paragraph from '../../components/Paragraph';
import StrongText from '../../components/StrongText';
import Title from '../../components/Title';
import ListItem from '../../components/ListItem';
import AccentParagraph from '../../components/AccentParagraph';
import DefaultText from '../../components/DefaultText';
import TextLink from '../../components/TextLink';

const InformationSystemsScreen = (props) => {
	return (
		<ScrollView>
			<View style={styles.textContainer}>
				<Paragraph>
					Students have unified login data to access all information
					systems at CZU, i.e. one login name and password. The login
					is unchanged throughout the study period. It consists of
					five letters and three digits. Students can change their
					password during their studies at any time. The password can
					only be changed in the University Information System
					is.czu.cz in the Information system set-up section.
				</Paragraph>
				<Paragraph>
					The login and password are published in the e-application
					within 10 days of enrolment. Current students still use the
					same information to log in. You must change your password
					after the first login.
				</Paragraph>
				<AccentParagraph>
					<StrongText style={styles.whiteText}>
						WI-FI EDUROAM
					</StrongText>
					<View>
						<ListItem style={styles.whiteText} pointerColor="white">
							<StrongText>login:</StrongText> xname@czu.cz
						</ListItem>
						<ListItem style={styles.whiteText} pointerColor="white">
							The password can be set in the My CZU app or the UIS
							in the Technology and its administration section
						</ListItem>
					</View>
					<StrongText style={styles.whiteText}>
						STUDENT E-MAIL
					</StrongText>
					<View>
						<ListItem style={styles.whiteText} pointerColor="white">
							<StrongText>login:</StrongText>{' '}
							xname@studenti.czu.cz
						</ListItem>
					</View>
					<StrongText style={styles.whiteText}>
						UIS AND ALL OTHERS
					</StrongText>
					<View>
						<ListItem style={styles.whiteText} pointerColor="white">
							<StrongText>login:</StrongText> xname
						</ListItem>
						<ListItem style={styles.whiteText} pointerColor="white">
							Change the generated password for both in the UIS
						</ListItem>
					</View>
				</AccentParagraph>
				<Title>University Information System (UIS)</Title>
				<Paragraph>Here, students will primarily find:</Paragraph>
				<View>
					<ListItem>personal schedule;</ListItem>
					<ListItem>overview of grades;</ListItem>
					<ListItem>
						enrolment in compulsory-elective and elective courses;
					</ListItem>
					<ListItem>news;</ListItem>
					<ListItem>possibility to register for exams;</ListItem>
					<ListItem>student‘s personal information;</ListItem>
					<ListItem>
						electronic application for accommodation scholarship;
					</ListItem>
					<ListItem>
						information on paid scholarships and fees associated
						with studying;
					</ListItem>
					<ListItem>teaching evaluation forms;</ListItem>
					<ListItem>password set up for Wi-Fi eduroam;</ListItem>
					<ListItem>theses system.</ListItem>
				</View>
				<Title>Moodle CZU</Title>
				<Paragraph>
					Moodle (
					<TextLink linkTo="https://moodle.czu.cz/">
						moodle.czu.cz
					</TextLink>
					) is a university-wide e-learning system designed to support
					teaching. In Moodle you will find courses on individual
					subjects and study materials, discussion forums,
					assignments, lectures, chats or polls.
				</Paragraph>
				<Paragraph>The Moodle system at CZU allows you to:</Paragraph>
				<View>
					<ListItem>track current events and deadlines;</ListItem>
					<ListItem>
						browse individual courses containing information and
						materials on selected subjects;
					</ListItem>
					<ListItem>
						communicate with other students and teachers;
					</ListItem>
					<ListItem>
						submit assignments online directly in the course;
					</ListItem>
					<ListItem>
						write tests and continuously check your knowledge;
					</ListItem>
					<ListItem>
						monitor the evaluation of course activities or the
						overall assessment for the course.
					</ListItem>
					<ListItem>
						have a constant overview of the current academic year.
					</ListItem>
				</View>
				<Title>Office 365 and school mailboxes</Title>
				<Paragraph>
					The CZU uses Microsoft Office 365 services. Students not
					only get an email but also an MS Office 365 license, which
					they can install on a variety of devices including PC/Mac,
					tablets, phones with Android, iPads and iPhones. In addition
					to Office 365, they get services such as online editing of
					documents, online storage with OneDrive or videoconferences.
					Licenses for <StrongText>Microsoft 365 A3</StrongText>{' '}
					products and services are{' '}
					<StrongText>free for the duration of the study</StrongText>{' '}
					(the condition for installation is the status of a CZU
					student). The student email can be found at{' '}
					<TextLink linkTo="https://mail.studenti.czu.cz">
						mail.studenti.czu.cz
					</TextLink>{' '}
					and is used for communication between the school and the
					student. Relevant information from the Study Department,
					from teachers, information about dates and exam results are
					sent to this email. In the case of email configuration on
					the phone, we require the security of the phone with a
					4-digit PIN code, and it is possible to use only the secure
					EAS protocol.{' '}
				</Paragraph>
				<AccentParagraph>
					<DefaultText
						style={{ color: 'white', textAlign: 'center' }}
					>
						More information and instructions can be found at{' '}
						<TextLink linkTo="https://moodle.czu.cz/">
							moodle.czu.cz
						</TextLink>{' '}
						in the Microsoft 365 course.
					</DefaultText>
				</AccentParagraph>
			</View>
		</ScrollView>
	);
};

InformationSystemsScreen.navigationOptions = (navigationData) => {
	return {
		headerTitle: 'Information systems',
	};
};

const styles = StyleSheet.create({
	textContainer: {
		paddingVertical: 10,
		paddingHorizontal: 20,
	},
	whiteText: {
		color: 'white',
	},
});

export default InformationSystemsScreen;
