import React from 'react';
import { View, StyleSheet, ScrollView } from 'react-native';
import Paragraph from '../../components/Paragraph';
import StrongText from '../../components/StrongText';
import AccentParagraph from '../../components/AccentParagraph';
import DefaultText from '../../components/DefaultText';
import TextLink from '../../components/TextLink';

const LibraryScreen = (props) => {
	return (
		<ScrollView>
			<View style={styles.textContainer}>
				<Paragraph>
					<StrongText>The CZU Library (LIB)</StrongText> provides
					access to all of the information resources you need for your
					studies.
				</Paragraph>
				<Paragraph>
					You can use the online library catalogue (
					<TextLink linkTo="https://aleph.czu.cz">
						aleph.czu.cz
					</TextLink>
					) or the EDS system (search box on the main page of LIB
					website) to find information on available study literature.
					The catalogue searches in printed documents stored at CZU,
					EDS, and in all information sources including electronic
					databases. You can search the catalogue without logging in.
					After logging in, registered users can not only search but
					also find information in the Reader section about their
					borrowed items and the status of borrowing requests (i.e.
					reservations for titles that someone else has borrowed) or
					extend the borrowing period. Before something is borrowed,
					the catalogue or EDS must first be checked to see if the
					requested document is in the library and that its borrow
					status is absent (it can be borrowed to take home). For
					books, the acquiring period is one month, for textbooks two
					months. The loan period can be extended twice for all
					publications.
				</Paragraph>
				<Paragraph>
					If the title has not been borrowed by another user, simply
					report its signature to the lending desk, and the librarian
					will lend it to the student upon presentation of his or her
					CZU/ISIC student card. All recommended literature is
					available on-site in the large study room throughout the
					day. University theses (bachelor‘s, master‘s and doctoral)
					are accessible through the UIS or on-site in the large study
					room. CZU students, employees (free of charge) and external
					interested parties can register with the library.
				</Paragraph>
				<AccentParagraph>
					<DefaultText
						style={{ color: 'white', textAlign: 'center' }}
					>
						You can find a lot of useful information at{' '}
						<TextLink linkTo="https://lib.czu.cz/en">
							lib.czu.cz
						</TextLink>
					</DefaultText>
				</AccentParagraph>
			</View>
		</ScrollView>
	);
};

LibraryScreen.navigationOptions = (navigationData) => {
	return {
		headerTitle: 'The CZU Library',
	};
};

const styles = StyleSheet.create({
	textContainer: {
		paddingVertical: 10,
		paddingHorizontal: 20,
	},
});

export default LibraryScreen;
